@@ -20,26 +20,26 @@ void compute_kc(double *vec_x, double *c, int *N, double *mean_x2,
 double Ma;
 int i,j,n_cut;
 
-	pc[0] = vec_x[0];
-	qc[0] = vec_x[0];
+	pc[0] = vec_x[0]*cos(*c);
+	qc[0] = vec_x[0]*sin(*c);
 
-	for(i = 1; i<*N; i++){
+	for(i = 1; i<(*N); i++){
 		pc[i] = pc[i-1] + vec_x[i]*cos(*c*(i+1));
 		qc[i] = qc[i-1] + vec_x[i]*sin(*c*(i+1));
         }
 	n_cut = *N/10;
 
-	for(i = 0; i<n_cut; i++){
+	for(i = 1; i<(n_cut+1); i++){
 		Ma = 0;
 		for(j = 0; j<(*N-i); j++){
-			Ma += pow((pc[j+(i+1)] - pc[j]), 2) + pow((qc[j+(i+1)] - qc[j]), 2);
+			Ma += pow((pc[j+i] - pc[j]), 2) + pow((qc[j+i] - qc[j]), 2);
 		}
 
-		Mc[i] = Ma/(*N-(i+1));
-		Dc[i] = Mc[i] - (*mean_x2)*(1 - cos(*c*(i+1)))/(1 - cos(*c));
+		Mc[i-1] = Ma/(*N-(i+1));
+		Dc[i-1] = Mc[i-1] - (*mean_x2)*(1 - cos(*c*(i+1)))/(1 - cos(*c));
 
 		if(*alpha>0){
-                    Dc[i] = Dc[i] + *mean_x2*sin(sqrt(2)*(i+1))*(*alpha);
+                    Dc[i-1] = Dc[i-1] + *mean_x2*sin(sqrt(2)*(i+1))*(*alpha);
                 }
 	}
 
